#include <libint2.h>
#include <GenericContract.h>
#include <OSVRRP0InBra_aB_p__0__k__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__l__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__m__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__pd__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__pp__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__pd__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__pp__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0.h>

#ifdef __cplusplus
extern "C" {
#endif
void _aB_P__0__K__1___TwoPRep_S__0__H__1___Ab__up_0_prereq(const Libint_t* inteval, LIBINT2_REALTYPE* parent_stack) {

LIBINT2_REALTYPE*const  stack = parent_stack;
{
const int hsi = 0;
{
const int lsi = 0;
{
const int vi = 0;
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1113)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_4[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_5[vi]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1116)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_3[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_4[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1119)*1+lsi)*1]), &(stack[((hsi*3+1116)*1+lsi)*1]), &(stack[((hsi*3+1113)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_3[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_4[vi]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1125)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_2[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_3[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1128)*1+lsi)*1]), &(stack[((hsi*3+1125)*1+lsi)*1]), &(stack[((hsi*3+1116)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_2[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_3[vi]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1134)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_5[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_6[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1137)*1+lsi)*1]), &(stack[((hsi*3+1113)*1+lsi)*1]), &(stack[((hsi*3+1134)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_4[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_5[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1143)*1+lsi)*1]), &(stack[((hsi*6+1119)*1+lsi)*1]), &(stack[((hsi*6+1137)*1+lsi)*1]), &(stack[((hsi*3+1116)*1+lsi)*1]), &(stack[((hsi*3+1113)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1153)*1+lsi)*1]), &(stack[((hsi*6+1128)*1+lsi)*1]), &(stack[((hsi*6+1119)*1+lsi)*1]), &(stack[((hsi*3+1125)*1+lsi)*1]), &(stack[((hsi*3+1116)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1163)*1+lsi)*1]), &(stack[((hsi*10+1153)*1+lsi)*1]), &(stack[((hsi*10+1143)*1+lsi)*1]), &(stack[((hsi*6+1128)*1+lsi)*1]), &(stack[((hsi*6+1119)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1116)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_1[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_2[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1178)*1+lsi)*1]), &(stack[((hsi*3+1116)*1+lsi)*1]), &(stack[((hsi*3+1125)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_1[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_2[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1184)*1+lsi)*1]), &(stack[((hsi*6+1178)*1+lsi)*1]), &(stack[((hsi*6+1128)*1+lsi)*1]), &(stack[((hsi*3+1116)*1+lsi)*1]), &(stack[((hsi*3+1125)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1194)*1+lsi)*1]), &(stack[((hsi*10+1184)*1+lsi)*1]), &(stack[((hsi*10+1153)*1+lsi)*1]), &(stack[((hsi*6+1178)*1+lsi)*1]), &(stack[((hsi*6+1128)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1125)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_6[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_7[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1128)*1+lsi)*1]), &(stack[((hsi*3+1134)*1+lsi)*1]), &(stack[((hsi*3+1125)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_5[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_6[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1209)*1+lsi)*1]), &(stack[((hsi*6+1137)*1+lsi)*1]), &(stack[((hsi*6+1128)*1+lsi)*1]), &(stack[((hsi*3+1113)*1+lsi)*1]), &(stack[((hsi*3+1134)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1219)*1+lsi)*1]), &(stack[((hsi*10+1143)*1+lsi)*1]), &(stack[((hsi*10+1209)*1+lsi)*1]), &(stack[((hsi*6+1119)*1+lsi)*1]), &(stack[((hsi*6+1137)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1234)*1+lsi)*1]), &(stack[((hsi*15+1163)*1+lsi)*1]), &(stack[((hsi*15+1219)*1+lsi)*1]), &(stack[((hsi*10+1153)*1+lsi)*1]), &(stack[((hsi*10+1143)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1255)*1+lsi)*1]), &(stack[((hsi*15+1194)*1+lsi)*1]), &(stack[((hsi*15+1163)*1+lsi)*1]), &(stack[((hsi*10+1184)*1+lsi)*1]), &(stack[((hsi*10+1153)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1276)*1+lsi)*1]), &(stack[((hsi*21+1255)*1+lsi)*1]), &(stack[((hsi*21+1234)*1+lsi)*1]), &(stack[((hsi*15+1194)*1+lsi)*1]), &(stack[((hsi*15+1163)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1113)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_7[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_8[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1119)*1+lsi)*1]), &(stack[((hsi*3+1125)*1+lsi)*1]), &(stack[((hsi*3+1113)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_6[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_7[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1153)*1+lsi)*1]), &(stack[((hsi*6+1128)*1+lsi)*1]), &(stack[((hsi*6+1119)*1+lsi)*1]), &(stack[((hsi*3+1134)*1+lsi)*1]), &(stack[((hsi*3+1125)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1304)*1+lsi)*1]), &(stack[((hsi*10+1209)*1+lsi)*1]), &(stack[((hsi*10+1153)*1+lsi)*1]), &(stack[((hsi*6+1137)*1+lsi)*1]), &(stack[((hsi*6+1128)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1319)*1+lsi)*1]), &(stack[((hsi*15+1219)*1+lsi)*1]), &(stack[((hsi*15+1304)*1+lsi)*1]), &(stack[((hsi*10+1143)*1+lsi)*1]), &(stack[((hsi*10+1209)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1340)*1+lsi)*1]), &(stack[((hsi*21+1234)*1+lsi)*1]), &(stack[((hsi*21+1319)*1+lsi)*1]), &(stack[((hsi*15+1163)*1+lsi)*1]), &(stack[((hsi*15+1219)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+1368)*1+lsi)*1]), &(stack[((hsi*28+1276)*1+lsi)*1]), &(stack[((hsi*28+1340)*1+lsi)*1]), &(stack[((hsi*21+1255)*1+lsi)*1]), &(stack[((hsi*21+1234)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1134)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_0[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_1[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1137)*1+lsi)*1]), &(stack[((hsi*3+1134)*1+lsi)*1]), &(stack[((hsi*3+1116)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_0[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_1[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1143)*1+lsi)*1]), &(stack[((hsi*6+1137)*1+lsi)*1]), &(stack[((hsi*6+1178)*1+lsi)*1]), &(stack[((hsi*3+1134)*1+lsi)*1]), &(stack[((hsi*3+1116)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1163)*1+lsi)*1]), &(stack[((hsi*10+1143)*1+lsi)*1]), &(stack[((hsi*10+1184)*1+lsi)*1]), &(stack[((hsi*6+1137)*1+lsi)*1]), &(stack[((hsi*6+1178)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1404)*1+lsi)*1]), &(stack[((hsi*15+1163)*1+lsi)*1]), &(stack[((hsi*15+1194)*1+lsi)*1]), &(stack[((hsi*10+1143)*1+lsi)*1]), &(stack[((hsi*10+1184)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1425)*1+lsi)*1]), &(stack[((hsi*21+1404)*1+lsi)*1]), &(stack[((hsi*21+1255)*1+lsi)*1]), &(stack[((hsi*15+1163)*1+lsi)*1]), &(stack[((hsi*15+1194)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+1163)*1+lsi)*1]), &(stack[((hsi*28+1425)*1+lsi)*1]), &(stack[((hsi*28+1276)*1+lsi)*1]), &(stack[((hsi*21+1404)*1+lsi)*1]), &(stack[((hsi*21+1255)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*108+1453)*1+lsi)*1]), &(stack[((hsi*36+1163)*1+lsi)*1]), &(stack[((hsi*36+1368)*1+lsi)*1]), &(stack[((hsi*28+1276)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*108+0)*1+lsi)*1]),&(stack[((hsi*108+1453)*1+lsi)*1]),108);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1116)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_8[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_9[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1255)*1+lsi)*1]), &(stack[((hsi*3+1113)*1+lsi)*1]), &(stack[((hsi*3+1116)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_7[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_8[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1199)*1+lsi)*1]), &(stack[((hsi*6+1119)*1+lsi)*1]), &(stack[((hsi*6+1255)*1+lsi)*1]), &(stack[((hsi*3+1125)*1+lsi)*1]), &(stack[((hsi*3+1113)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1261)*1+lsi)*1]), &(stack[((hsi*10+1153)*1+lsi)*1]), &(stack[((hsi*10+1199)*1+lsi)*1]), &(stack[((hsi*6+1128)*1+lsi)*1]), &(stack[((hsi*6+1119)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1404)*1+lsi)*1]), &(stack[((hsi*15+1304)*1+lsi)*1]), &(stack[((hsi*15+1261)*1+lsi)*1]), &(stack[((hsi*10+1209)*1+lsi)*1]), &(stack[((hsi*10+1153)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1125)*1+lsi)*1]), &(stack[((hsi*21+1319)*1+lsi)*1]), &(stack[((hsi*21+1404)*1+lsi)*1]), &(stack[((hsi*15+1219)*1+lsi)*1]), &(stack[((hsi*15+1304)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+1561)*1+lsi)*1]), &(stack[((hsi*28+1340)*1+lsi)*1]), &(stack[((hsi*28+1125)*1+lsi)*1]), &(stack[((hsi*21+1234)*1+lsi)*1]), &(stack[((hsi*21+1319)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+1209)*1+lsi)*1]), &(stack[((hsi*36+1368)*1+lsi)*1]), &(stack[((hsi*36+1561)*1+lsi)*1]), &(stack[((hsi*28+1276)*1+lsi)*1]), &(stack[((hsi*28+1340)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+1597)*1+lsi)*1]), &(stack[((hsi*36+1163)*1+lsi)*1]), &(stack[((hsi*36+1368)*1+lsi)*1]), &(stack[((hsi*28+1425)*1+lsi)*1]), &(stack[((hsi*28+1276)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*135+1642)*1+lsi)*1]), &(stack[((hsi*45+1597)*1+lsi)*1]), &(stack[((hsi*45+1209)*1+lsi)*1]), &(stack[((hsi*36+1368)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*135+108)*1+lsi)*1]),&(stack[((hsi*135+1642)*1+lsi)*1]),135);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1276)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_9[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_10[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1425)*1+lsi)*1]), &(stack[((hsi*3+1116)*1+lsi)*1]), &(stack[((hsi*3+1276)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_8[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_9[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1279)*1+lsi)*1]), &(stack[((hsi*6+1255)*1+lsi)*1]), &(stack[((hsi*6+1425)*1+lsi)*1]), &(stack[((hsi*3+1113)*1+lsi)*1]), &(stack[((hsi*3+1116)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1289)*1+lsi)*1]), &(stack[((hsi*10+1199)*1+lsi)*1]), &(stack[((hsi*10+1279)*1+lsi)*1]), &(stack[((hsi*6+1119)*1+lsi)*1]), &(stack[((hsi*6+1255)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1431)*1+lsi)*1]), &(stack[((hsi*15+1261)*1+lsi)*1]), &(stack[((hsi*15+1289)*1+lsi)*1]), &(stack[((hsi*10+1153)*1+lsi)*1]), &(stack[((hsi*10+1199)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1777)*1+lsi)*1]), &(stack[((hsi*21+1404)*1+lsi)*1]), &(stack[((hsi*21+1431)*1+lsi)*1]), &(stack[((hsi*15+1304)*1+lsi)*1]), &(stack[((hsi*15+1261)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+1805)*1+lsi)*1]), &(stack[((hsi*28+1125)*1+lsi)*1]), &(stack[((hsi*28+1777)*1+lsi)*1]), &(stack[((hsi*21+1319)*1+lsi)*1]), &(stack[((hsi*21+1404)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+1841)*1+lsi)*1]), &(stack[((hsi*36+1561)*1+lsi)*1]), &(stack[((hsi*36+1805)*1+lsi)*1]), &(stack[((hsi*28+1340)*1+lsi)*1]), &(stack[((hsi*28+1125)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+1304)*1+lsi)*1]), &(stack[((hsi*45+1209)*1+lsi)*1]), &(stack[((hsi*45+1841)*1+lsi)*1]), &(stack[((hsi*36+1368)*1+lsi)*1]), &(stack[((hsi*36+1561)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+1886)*1+lsi)*1]), &(stack[((hsi*45+1597)*1+lsi)*1]), &(stack[((hsi*45+1209)*1+lsi)*1]), &(stack[((hsi*36+1163)*1+lsi)*1]), &(stack[((hsi*36+1368)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*165+1941)*1+lsi)*1]), &(stack[((hsi*55+1886)*1+lsi)*1]), &(stack[((hsi*55+1304)*1+lsi)*1]), &(stack[((hsi*45+1209)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*165+243)*1+lsi)*1]),&(stack[((hsi*165+1941)*1+lsi)*1]),165);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1113)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_10[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_11[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1119)*1+lsi)*1]), &(stack[((hsi*3+1276)*1+lsi)*1]), &(stack[((hsi*3+1113)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_9[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_10[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1153)*1+lsi)*1]), &(stack[((hsi*6+1425)*1+lsi)*1]), &(stack[((hsi*6+1119)*1+lsi)*1]), &(stack[((hsi*3+1116)*1+lsi)*1]), &(stack[((hsi*3+1276)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1359)*1+lsi)*1]), &(stack[((hsi*10+1279)*1+lsi)*1]), &(stack[((hsi*10+1153)*1+lsi)*1]), &(stack[((hsi*6+1255)*1+lsi)*1]), &(stack[((hsi*6+1425)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1163)*1+lsi)*1]), &(stack[((hsi*15+1289)*1+lsi)*1]), &(stack[((hsi*15+1359)*1+lsi)*1]), &(stack[((hsi*10+1199)*1+lsi)*1]), &(stack[((hsi*10+1279)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1374)*1+lsi)*1]), &(stack[((hsi*21+1431)*1+lsi)*1]), &(stack[((hsi*21+1163)*1+lsi)*1]), &(stack[((hsi*15+1261)*1+lsi)*1]), &(stack[((hsi*15+1289)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+2106)*1+lsi)*1]), &(stack[((hsi*28+1777)*1+lsi)*1]), &(stack[((hsi*28+1374)*1+lsi)*1]), &(stack[((hsi*21+1404)*1+lsi)*1]), &(stack[((hsi*21+1431)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+2142)*1+lsi)*1]), &(stack[((hsi*36+1805)*1+lsi)*1]), &(stack[((hsi*36+2106)*1+lsi)*1]), &(stack[((hsi*28+1125)*1+lsi)*1]), &(stack[((hsi*28+1777)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+2187)*1+lsi)*1]), &(stack[((hsi*45+1841)*1+lsi)*1]), &(stack[((hsi*45+2142)*1+lsi)*1]), &(stack[((hsi*36+1561)*1+lsi)*1]), &(stack[((hsi*36+1805)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*66+2242)*1+lsi)*1]), &(stack[((hsi*55+1304)*1+lsi)*1]), &(stack[((hsi*55+2187)*1+lsi)*1]), &(stack[((hsi*45+1209)*1+lsi)*1]), &(stack[((hsi*45+1841)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*66+2308)*1+lsi)*1]), &(stack[((hsi*55+1886)*1+lsi)*1]), &(stack[((hsi*55+1304)*1+lsi)*1]), &(stack[((hsi*45+1597)*1+lsi)*1]), &(stack[((hsi*45+1209)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*198+2374)*1+lsi)*1]), &(stack[((hsi*66+2308)*1+lsi)*1]), &(stack[((hsi*66+2242)*1+lsi)*1]), &(stack[((hsi*55+1304)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*198+408)*1+lsi)*1]),&(stack[((hsi*198+2374)*1+lsi)*1]),198);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1116)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_11[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_12[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1184)*1+lsi)*1]), &(stack[((hsi*3+1113)*1+lsi)*1]), &(stack[((hsi*3+1116)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_10[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_11[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1190)*1+lsi)*1]), &(stack[((hsi*6+1119)*1+lsi)*1]), &(stack[((hsi*6+1184)*1+lsi)*1]), &(stack[((hsi*3+1276)*1+lsi)*1]), &(stack[((hsi*3+1113)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1561)*1+lsi)*1]), &(stack[((hsi*10+1153)*1+lsi)*1]), &(stack[((hsi*10+1190)*1+lsi)*1]), &(stack[((hsi*6+1425)*1+lsi)*1]), &(stack[((hsi*6+1119)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1200)*1+lsi)*1]), &(stack[((hsi*15+1359)*1+lsi)*1]), &(stack[((hsi*15+1561)*1+lsi)*1]), &(stack[((hsi*10+1279)*1+lsi)*1]), &(stack[((hsi*10+1153)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1125)*1+lsi)*1]), &(stack[((hsi*21+1163)*1+lsi)*1]), &(stack[((hsi*21+1200)*1+lsi)*1]), &(stack[((hsi*15+1289)*1+lsi)*1]), &(stack[((hsi*15+1359)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+1221)*1+lsi)*1]), &(stack[((hsi*28+1374)*1+lsi)*1]), &(stack[((hsi*28+1125)*1+lsi)*1]), &(stack[((hsi*21+1431)*1+lsi)*1]), &(stack[((hsi*21+1163)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+1576)*1+lsi)*1]), &(stack[((hsi*36+2106)*1+lsi)*1]), &(stack[((hsi*36+1221)*1+lsi)*1]), &(stack[((hsi*28+1777)*1+lsi)*1]), &(stack[((hsi*28+1374)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+2572)*1+lsi)*1]), &(stack[((hsi*45+2142)*1+lsi)*1]), &(stack[((hsi*45+1576)*1+lsi)*1]), &(stack[((hsi*36+1805)*1+lsi)*1]), &(stack[((hsi*36+2106)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*66+2627)*1+lsi)*1]), &(stack[((hsi*55+2187)*1+lsi)*1]), &(stack[((hsi*55+2572)*1+lsi)*1]), &(stack[((hsi*45+1841)*1+lsi)*1]), &(stack[((hsi*45+2142)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__pp__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*78+1777)*1+lsi)*1]), &(stack[((hsi*66+2242)*1+lsi)*1]), &(stack[((hsi*66+2627)*1+lsi)*1]), &(stack[((hsi*55+1304)*1+lsi)*1]), &(stack[((hsi*55+2187)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__pp__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*78+2693)*1+lsi)*1]), &(stack[((hsi*66+2308)*1+lsi)*1]), &(stack[((hsi*66+2242)*1+lsi)*1]), &(stack[((hsi*55+1886)*1+lsi)*1]), &(stack[((hsi*55+1304)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__pp__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*234+2771)*1+lsi)*1]), &(stack[((hsi*78+2693)*1+lsi)*1]), &(stack[((hsi*78+1777)*1+lsi)*1]), &(stack[((hsi*66+2242)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*234+606)*1+lsi)*1]),&(stack[((hsi*234+2771)*1+lsi)*1]),234);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1257)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_12[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_13[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1260)*1+lsi)*1]), &(stack[((hsi*3+1116)*1+lsi)*1]), &(stack[((hsi*3+1257)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_11[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_12[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1266)*1+lsi)*1]), &(stack[((hsi*6+1184)*1+lsi)*1]), &(stack[((hsi*6+1260)*1+lsi)*1]), &(stack[((hsi*3+1113)*1+lsi)*1]), &(stack[((hsi*3+1116)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1855)*1+lsi)*1]), &(stack[((hsi*10+1190)*1+lsi)*1]), &(stack[((hsi*10+1266)*1+lsi)*1]), &(stack[((hsi*6+1119)*1+lsi)*1]), &(stack[((hsi*6+1184)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1621)*1+lsi)*1]), &(stack[((hsi*15+1561)*1+lsi)*1]), &(stack[((hsi*15+1855)*1+lsi)*1]), &(stack[((hsi*10+1153)*1+lsi)*1]), &(stack[((hsi*10+1190)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1257)*1+lsi)*1]), &(stack[((hsi*21+1200)*1+lsi)*1]), &(stack[((hsi*21+1621)*1+lsi)*1]), &(stack[((hsi*15+1359)*1+lsi)*1]), &(stack[((hsi*15+1561)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+1285)*1+lsi)*1]), &(stack[((hsi*28+1125)*1+lsi)*1]), &(stack[((hsi*28+1257)*1+lsi)*1]), &(stack[((hsi*21+1163)*1+lsi)*1]), &(stack[((hsi*21+1200)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+1855)*1+lsi)*1]), &(stack[((hsi*36+1221)*1+lsi)*1]), &(stack[((hsi*36+1285)*1+lsi)*1]), &(stack[((hsi*28+1374)*1+lsi)*1]), &(stack[((hsi*28+1125)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+1257)*1+lsi)*1]), &(stack[((hsi*45+1576)*1+lsi)*1]), &(stack[((hsi*45+1855)*1+lsi)*1]), &(stack[((hsi*36+2106)*1+lsi)*1]), &(stack[((hsi*36+1221)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*66+1113)*1+lsi)*1]), &(stack[((hsi*55+2572)*1+lsi)*1]), &(stack[((hsi*55+1257)*1+lsi)*1]), &(stack[((hsi*45+2142)*1+lsi)*1]), &(stack[((hsi*45+1576)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__pp__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*78+1179)*1+lsi)*1]), &(stack[((hsi*66+2627)*1+lsi)*1]), &(stack[((hsi*66+1113)*1+lsi)*1]), &(stack[((hsi*55+2187)*1+lsi)*1]), &(stack[((hsi*55+2572)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__pd__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*91+1257)*1+lsi)*1]), &(stack[((hsi*78+1777)*1+lsi)*1]), &(stack[((hsi*78+1179)*1+lsi)*1]), &(stack[((hsi*66+2242)*1+lsi)*1]), &(stack[((hsi*66+2627)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__pd__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*91+1113)*1+lsi)*1]), &(stack[((hsi*78+2693)*1+lsi)*1]), &(stack[((hsi*78+1777)*1+lsi)*1]), &(stack[((hsi*66+2308)*1+lsi)*1]), &(stack[((hsi*66+2242)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__pd__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*273+3005)*1+lsi)*1]), &(stack[((hsi*91+1113)*1+lsi)*1]), &(stack[((hsi*91+1257)*1+lsi)*1]), &(stack[((hsi*78+1777)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*273+840)*1+lsi)*1]),&(stack[((hsi*273+3005)*1+lsi)*1]),273);
}
}
}
const int hsi = 0;
const int lsi = 0;
const int vi = 0;
/** Number of flops = 1113 */
}

#ifdef __cplusplus
};
#endif
